@@ -2,11 +2,14 @@
 
 export PATH=/usr/bin:/bin:/usr/sbin:/sbin
 
-version=2.1.25
+version=2.1.27
 ARCHIVE=cyrus-sasl-$version
 ARCHIVE_NAME=$ARCHIVE.tar.gz
 ARCHIVE_PATCH=$ARCHIVE.patch
-url=ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/$ARCHIVE_NAME
+#url=ftp://ftp.andrew.cmu.edu/pub/cyrus-mail/$ARCHIVE_NAME
+#url=ftp://ftp.cyrusimap.org/cyrus-sasl/$ARCHIVE_NAME
+#url=https://www.cyrusimap.org/releases/$ARCHIVE_NAME
+url=https://github.com/cyrusimap/cyrus-sasl/releases/download/$ARCHIVE/$ARCHIVE_NAME
 patchfile=cyrus-2.1.25-libetpan.patch
 
 scriptdir="`pwd`"
@@ -39,10 +42,10 @@ if test -f "$current_dir/packages/$ARCHIVE_NAME" ; then
 	:
 else
 	echo "download source package - $url"
-	
+
 	mkdir -p "$current_dir/packages"
   cd "$current_dir/packages"
-	curl -O "$url"
+	curl -L -O "$url"
 	if test x$? != x0 ; then
 		echo fetch of $ARCHIVE_NAME failed
 		exit 1
@@ -71,9 +74,9 @@ cd "$srcdir/$ARCHIVE"
 patch -p1 < $current_dir/$patchfile
 # patch source files
 cd "$srcdir/$ARCHIVE/include"
-sed -E 's/\.\/makemd5 /.\/makemd5i386 /' < Makefile.am > Makefile.am.new
+sed -E 's/\.\/\$< /.\/\$<i386 /' < Makefile.am > Makefile.am.new
 mv Makefile.am.new Makefile.am
-sed -E 's/\.\/makemd5 /.\/makemd5i386 /' < Makefile.in > Makefile.in.new
+sed -E 's/\.\/\$< /.\/\$<i386 /' < Makefile.in > Makefile.in.new
 mv Makefile.in.new Makefile.in
 cd "$srcdir/$ARCHIVE/lib"
 sed -E 's/\$\(AR\) cru \.libs\/\$@ \$\(SASL_STATIC_OBJS\)/&; \$\(RANLIB\) .libs\/\$@/' < Makefile.in > Makefile.in.new
@@ -111,20 +114,25 @@ LIB_NAME=$ARCHIVE
 TARGETS="iPhoneOS iPhoneSimulator"
 
 SDK_IOS_MIN_VERSION=7.0
-SDK_IOS_VERSION="`xcodebuild -version -sdk 2>/dev/null | egrep SDKVersion | tail -n 1 | sed -E -n -e 's|SDKVersion: *(.*) *$|\1|p'`"
+SDK_IOS_VERSION="`xcodebuild -showsdks 2>/dev/null | grep iphoneos | sed 's/.*iphoneos\(.*\)/\1/'`"
 BUILD_DIR="$tmpdir/build"
 INSTALL_PATH="${BUILD_DIR}/${LIB_NAME}/universal"
+BITCODE_FLAGS="-fembed-bitcode"
+if test "x$NOBITCODE" != x ; then
+   BITCODE_FLAGS=""
+fi
 
 for TARGET in $TARGETS; do
 
     DEVELOPER="$(xcode-select --print-path)"
-    SYSROOT="`xcodebuild -version -sdk 2>/dev/null | egrep $TARGET -B 3 | egrep '^Path: '| egrep $SDK_IOS_VERSION | sort -u | tail -n 1| cut -d ' ' -f 2`"
+    SDK_ID="$(echo "$TARGET$SDK_IOS_VERSION" | tr A-Z a-z)"
+    SYSROOT="$(xcodebuild -version -sdk "$SDK_ID" 2>/dev/null | egrep '^Path: ' | cut -d ' ' -f 2)"
 
     case $TARGET in
-        (iPhoneOS) 
+        (iPhoneOS)
             ARCH=arm
             MARCHS="armv7 armv7s arm64"
-            EXTRA_FLAGS="-miphoneos-version-min=$SDK_IOS_MIN_VERSION"
+            EXTRA_FLAGS="$BITCODE_FLAGS -miphoneos-version-min=$SDK_IOS_MIN_VERSION"
             ;;
         (iPhoneSimulator)
             ARCH=i386
@@ -132,11 +140,11 @@ for TARGET in $TARGETS; do
             EXTRA_FLAGS="-miphoneos-version-min=$SDK_IOS_MIN_VERSION"
             ;;
     esac
-    
+
     for MARCH in $MARCHS; do
 				echo "building for $TARGET - $MARCH"
 				echo "*** building for $TARGET - $MARCH ***" >> "$logfile" 2>&1
-			
+
         PREFIX=${BUILD_DIR}/${LIB_NAME}/${TARGET}${SDK_IOS_VERSION}${MARCH}
         rm -rf $PREFIX
 
@@ -149,6 +157,7 @@ for TARGET in $TARGETS; do
         make -j 8 >> "$logfile" 2>&1
         if [[ "$?" != "0" ]]; then
           echo "CONFIGURE FAILED"
+          cat "$logfile"
           exit 1
         fi
         cd lib
@@ -162,6 +171,7 @@ for TARGET in $TARGETS; do
         cd ..
         if [[ "$?" != "0" ]]; then
           echo "BUILD FAILED"
+          cat "$logfile"
           exit 1
         fi
         make clean >> "$logfile" 2>&1
