@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.36 2009/12/19 00:56:15 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.38 2011/06/04 13:25:56 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -370,14 +370,12 @@ imap_body_media_basic_to_content_type(struct mailimap_media_basic *
   int discrete_type_type;
   int composite_type_type;
   int mime_type_type;
-  char * subtype;
   int r;
   int res;
 
   discrete_type = NULL;
   composite_type = NULL;
   discrete_type_extension = NULL;
-  subtype = NULL;
   discrete_type_type = 0;
   composite_type_type = 0;
   mime_type_type = 0;
@@ -502,7 +500,14 @@ imap_disposition_to_mime_disposition(struct mailimap_body_fld_dsp * imap_dsp,
   cur_token = 0;
   r = mailmime_disposition_type_parse(imap_dsp->dsp_type,
       strlen(imap_dsp->dsp_type), &cur_token, &dsp_type);
-  if (r != MAILIMF_NO_ERROR) {
+  if (r == MAILIMF_ERROR_PARSE) {
+    dsp_type = mailmime_disposition_type_new(MAILMIME_DISPOSITION_TYPE_ATTACHMENT, NULL);
+    if (dsp_type == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto err;
+    }
+  }
+  else if (r != MAILIMF_NO_ERROR) {
     res = MAILIMF_ERROR_PARSE;
     goto err;
   }
@@ -751,6 +756,7 @@ static int
 imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
     struct mailimap_body_fld_dsp * imap_dsp,
     struct mailimap_body_fld_lang * imap_lang,
+    char * imap_loc,
     struct mailmime_fields ** result,
     uint32_t * pbody_size)
 {
@@ -762,6 +768,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
   char * description;
   struct mailmime_disposition * dsp;
   struct mailmime_language * lang;
+  char * loc;
   int type;
   int r;
   int res;
@@ -786,7 +793,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
       }
 
       mime_field = mailmime_field_new(type, NULL,
-          NULL, id, NULL, 0, NULL, NULL);
+          NULL, id, NULL, 0, NULL, NULL, NULL);
       if (mime_field == NULL) {
 	free(id);
 	res = MAIL_ERROR_MEMORY;
@@ -810,7 +817,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
       }
 
       mime_field = mailmime_field_new(type, NULL,
-          NULL, NULL, description, 0, NULL, NULL);
+          NULL, NULL, description, 0, NULL, NULL, NULL);
       if (mime_field == NULL) {
 	free(description);
 	res = MAIL_ERROR_MEMORY;
@@ -870,7 +877,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
       }
 
       mime_field = mailmime_field_new(type, NULL,
-          encoding, NULL, NULL, 0, NULL, NULL);
+          encoding, NULL, NULL, 0, NULL, NULL, NULL);
       if (mime_field == NULL) {
 	mailmime_mechanism_free(encoding);
 	res = MAIL_ERROR_MEMORY;
@@ -897,7 +904,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
       type = MAILMIME_FIELD_DISPOSITION;
       
       mime_field = mailmime_field_new(type, NULL,
-				      NULL, NULL, NULL, 0, dsp, NULL);
+				      NULL, NULL, NULL, 0, dsp, NULL, NULL);
       if (mime_field == NULL) {
 	mailmime_disposition_free(dsp);
 	res = MAIL_ERROR_MEMORY;
@@ -931,7 +938,7 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
       type = MAILMIME_FIELD_LANGUAGE;
 
       mime_field = mailmime_field_new(type, NULL,
-          NULL, NULL, NULL, 0, NULL, lang);
+          NULL, NULL, NULL, 0, NULL, lang, NULL);
       if (mime_field == NULL) {
         mailmime_language_free(lang);
         res = MAIL_ERROR_MEMORY;
@@ -947,6 +954,31 @@ imap_body_fields_to_mime_fields(struct mailimap_body_fields * body_fields,
     }
   }
 
+  if (imap_loc != NULL) {
+    type = MAILMIME_FIELD_LOCATION;
+    
+    loc = strdup(imap_loc);
+    if (loc == NULL) {
+      res = MAIL_ERROR_MEMORY;
+      goto free_list;
+    }
+    
+    mime_field = mailmime_field_new(type, NULL,
+                                    NULL, NULL, NULL, 0, NULL, NULL, loc);
+    if (mime_field == NULL) {
+      mailmime_location_free(loc);
+      res = MAIL_ERROR_MEMORY;
+      goto free_list;
+    }
+    
+    r = clist_append(list, mime_field);
+    if (r != 0) {
+      mailmime_field_free(mime_field);
+      res = MAIL_ERROR_MEMORY;
+      goto free_list;
+    }
+  }
+  
   mime_fields = mailmime_fields_new(list);
   if (mime_fields == NULL) {
     res = MAIL_ERROR_MEMORY;
@@ -990,10 +1022,11 @@ imap_body_type_basic_to_body(struct mailimap_body_type_basic *
     r = imap_body_fields_to_mime_fields(imap_type_basic->bd_fields,
         body_ext_1part->bd_disposition,
         body_ext_1part->bd_language,
+        body_ext_1part->bd_loc,
         &mime_fields, &mime_size);
   else
     r = imap_body_fields_to_mime_fields(imap_type_basic->bd_fields,
-        NULL, NULL,
+        NULL, NULL, NULL,
         &mime_fields, &mime_size);
   if (r != MAIL_NO_ERROR) {
     res = r;
@@ -1045,13 +1078,14 @@ imap_body_type_text_to_body(struct mailimap_body_type_text *
 
   if (body_ext_1part == NULL) {
     r = imap_body_fields_to_mime_fields(imap_type_text->bd_fields,
-        NULL, NULL,
+        NULL, NULL, NULL,
         &mime_fields, &mime_size);
   }
   else {
     r = imap_body_fields_to_mime_fields(imap_type_text->bd_fields,
         body_ext_1part->bd_disposition,
         body_ext_1part->bd_language,
+        body_ext_1part->bd_loc,
         &mime_fields, &mime_size);
   }
   if (r != MAIL_NO_ERROR) {
@@ -1232,12 +1266,12 @@ imap_body_type_msg_to_body(struct mailimap_body_type_msg *
   
   if (body_ext_1part != NULL) {
   	r = imap_body_fields_to_mime_fields(imap_type_msg->bd_fields,
-      	body_ext_1part->bd_disposition, body_ext_1part->bd_language,
+      	body_ext_1part->bd_disposition, body_ext_1part->bd_language, body_ext_1part->bd_loc,
       	&mime_fields, &mime_size);
   }
   else {
   	r = imap_body_fields_to_mime_fields(imap_type_msg->bd_fields,
-      	NULL, NULL,
+      	NULL, NULL, NULL,
       	&mime_fields, &mime_size);
   }
   if (r != MAIL_NO_ERROR) {
@@ -1381,6 +1415,7 @@ imap_body_type_mpart_to_body(struct mailimap_body_type_mpart *
     r = imap_body_fields_to_mime_fields(NULL,
         type_mpart->bd_ext_mpart->bd_disposition,
         type_mpart->bd_ext_mpart->bd_language,
+        type_mpart->bd_ext_mpart->bd_loc,
         &mime_fields, &mime_size);
   }
   if (r != MAIL_NO_ERROR) {
@@ -1613,11 +1648,9 @@ imap_mailbox_list_to_mailbox_list(clist * imap_mailbox_list,
   clist * list;
   struct mailimf_mailbox_list * mb_list;
   int r;
-  int res;
 
   list = clist_new();
   if (list == NULL) {
-    res = MAIL_ERROR_MEMORY;
     goto err;
   }
 
@@ -1633,21 +1666,18 @@ imap_mailbox_list_to_mailbox_list(clist * imap_mailbox_list,
 
     r = imap_address_to_mailbox(imap_addr, &mb);
     if (r != MAIL_NO_ERROR) {
-      res = r;
       goto free_list;
     }
     
     r = clist_append(list, mb);
     if (r != 0) {
       mailimf_mailbox_free(mb);
-      res = MAIL_ERROR_MEMORY;
       goto free_list;
     }
   }
 
   mb_list = mailimf_mailbox_list_new(list);
   if (mb_list == NULL) {
-    res = MAIL_ERROR_MEMORY;
     goto free_list;
   }
 
@@ -2954,6 +2984,10 @@ int imap_msg_list_to_imap_set(clist * msg_list,
     }
 
     pindex = clist_content(cur);
+    if (pindex == NULL) {
+      // Make clang static analyzer happy.
+      break;
+    }
 
     if (!previous_valid) {
       first_seq = * pindex;
@@ -3648,21 +3682,11 @@ imapdriver_get_cached_envelope(struct mail_cache_db * cache_db,
     mailsession * session, mailmessage * msg,
     struct mailimf_fields ** result)
 {
-#if 0
-  mailsession * imap_session;
-#endif
-  mailimap * imap;
   int r;
   struct mailimf_fields * fields;
   int res;
   char keyname[PATH_MAX];
   
-#if 0
-  imap_session = cached_session_get_ancestor(session);
-  imap = ((struct imap_session_state_data *) (imap_session->data))->session;
-#endif
-  imap = cached_session_get_imap_session(session);
-
   generate_key_from_message(keyname, PATH_MAX,
 			    msg, MAILIMAP_MSG_ATT_ENVELOPE);
 
