@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_types_helper.h,v 1.16 2005/06/01 12:22:19 smarinier Exp $
+ * $Id: mailmime_types_helper.h,v 1.17 2008/01/14 17:13:53 hoa Exp $
  */
 
 #ifndef MAILMIME_TYPES_HELPER_H
@@ -190,6 +190,13 @@ LIBETPAN_EXPORT
 struct mailmime_fields * mailmime_fields_new_filename(int dsp_type,
     char * filename, int encoding_type);
 
+LIBETPAN_EXPORT
+struct mailmime_parameter *
+mailmime_param_new_with_data(char * name, char * value);
+
+LIBETPAN_EXPORT
+char * mailmime_generate_boundary(void);
+
 #ifdef __cplusplus
 }
 #endif
