@@ -41,6 +41,7 @@
 
 #include "newsnntp.h"
 
+#include "mailstream_cfstream.h"
 #include "connect.h"
 
 #ifdef HAVE_NETINET_IN_H
@@ -54,11 +55,21 @@
 #define SERVICE_NAME_NNTP "nntp"
 #define SERVICE_TYPE_TCP "tcp"
 
+#if HAVE_CFNETWORK
+static int newsnntp_cfsocket_connect(newsnntp * f, const char * server, uint16_t port);
+#endif
+
 int newsnntp_socket_connect(newsnntp * f, const char * server, uint16_t port)
 {
   int s;
   mailstream * stream;
 
+#if HAVE_CFNETWORK
+  if (mailstream_cfstream_enabled) {
+    return newsnntp_cfsocket_connect(f, server, port);
+  }
+#endif
+  
   if (port == 0) {
     port = mail_get_service_port(SERVICE_NAME_NNTP, SERVICE_TYPE_TCP);
     if (port == 0)
@@ -67,19 +78,34 @@ int newsnntp_socket_connect(newsnntp * f, const char * server, uint16_t port)
 
   /* Connection */
 
-  s = mail_tcp_connect(server, port);
+  s = mail_tcp_connect_timeout(server, port, f->nntp_timeout);
   if (s == -1)
     return NEWSNNTP_ERROR_CONNECTION_REFUSED;
 
-  stream = mailstream_socket_open(s);
+  stream = mailstream_socket_open_timeout(s, f->nntp_timeout);
   if (stream == NULL) {
 #ifdef WIN32
-	closesocket(s);
+    closesocket(s);
 #else
     close(s);
 #endif
+		
     return NEWSNNTP_ERROR_MEMORY;
   }
 
   return newsnntp_connect(f, stream);
 }
+
+#if HAVE_CFNETWORK
+static int newsnntp_cfsocket_connect(newsnntp * f, const char * server, uint16_t port)
+{
+  mailstream * stream;
+  
+  stream = mailstream_cfstream_open_timeout(server, port, f->nntp_timeout);
+  if (stream == NULL) {
+    return NEWSNNTP_ERROR_STREAM;
+  }
+  
+  return newsnntp_connect(f, stream);
+}
+#endif
