@@ -146,22 +146,20 @@ int main(int argc, char ** argv)
   char * user;
   char * password;
   int auth_type;
+  bool xoauth2;
   char * path;
   char * cache_directory;
   char * flags_directory;
   struct mailstorage * storage;
-  int cached;
   struct mailfolder * folder;
 
   /* get options */
 
   r = parse_options(argc, argv,
       &driver, &server, &port, &connection_type,
-      &user, &password, &auth_type,
+      &user, &password, &auth_type, &xoauth2,
       &path, &cache_directory, &flags_directory);
 
-  cached = (cache_directory != NULL);
-
   /* build the storage structure */
 
   storage = mailstorage_new(NULL);
@@ -171,7 +169,7 @@ int main(int argc, char ** argv)
   }
 
   r = init_storage(storage, driver, server, port, connection_type,
-      user, password, auth_type, path, cache_directory, flags_directory);
+      user, password, auth_type, xoauth2, path, cache_directory, flags_directory);
   if (r != MAIL_NO_ERROR) {
     printf("error initializing storage\n");
     goto free_opt;
